Index: uspace/lib/c/arch/ia64/src/entry.S
===================================================================
--- uspace/lib/c/arch/ia64/src/entry.S	(revision ae7d03c05f24b857bbbdbcf3dafbf8ecc6c286ab)
+++ uspace/lib/c/arch/ia64/src/entry.S	(revision 9912f492e2fb139a10c05399ed342a71bef48acf)
@@ -29,5 +29,5 @@
 #include <abi/asmtool.h>
 
-.section .init, "ax"
+.text
 
 .org 0
@@ -42,6 +42,6 @@
 	movl gp = __gp
 
 	# Pass PCB pointer as the first argument to __libc_main
 	mov out0 = r2 ;;
-	br.call.sptk.many b0 = __libc_main
+	br.call.sptk.many b0 = __c_start
 
@@ -42,6 +42,6 @@
 	movl gp = __gp
 
-	# Pass PCB pointer as the first argument to __libc_main
+	# Pass PCB pointer as the first argument to __c_start
 	mov out0 = r2 ;;
